//============================================================================================================
//	$Id$
//
//	$Author$
//
//	$DateTime$
//============================================================================================================

#ifndef _LFC1_HPP_
#define _LFC1_HPP_

///	@mainpage
///
///	This library is an extension of the C++ standard library and the Boost C++ library.  Each sub-library
///	enhances C++ code reliability by providing the following capabilities:
///
///	-	(Config)  A set of functions used to manipulate a configuration file.
///
///	-	(Logging)  A set of enumerations and functions which provides a pre-configured interface to the
///		Boost.Log library.
///
///	-	(System)  A set of enumerations and classes which provides error codes and an error category for this
///		library.  This library provides an example of what is needed to extend the C++ diagnostic library.
///
///	-	(Udtsup)  A set of templates which provides exception/error handling for inserters, extractors and
///		manipulators of user-defined types.  These templates handle exceptions derived from std::bad_alloc,
///		std::exception and unknown exceptions.
///
///	-	(Filesystem)  A set of classes which extends the standard or Boost filesystem library.
///
///	-	(Iso)  A set of interfaces representing ISO standards.  These interfaces provide the ability to
///		interchange data sources for languages, countries and currencies defined by ISO standards.
///
///	-	(Isofile)  A set of classes implementing the interfaces defined in the ISO library where the data
///		sources are files formatted according to the ISO standards for languages, countries and currencies.
///		There is also an exception class which identifies missing parts in the data files.
///
///	-	(Checksum)  A set of interfaces and classes for checksum/hash calculation.  The interfaces provide the
///		ability to interchange checksum or hash calculators.  The classes provide the ability to calculate
///		checksums or hashes of a sequence of bytes in memory or in files.
///
///	-	(Codecvt)  A set of classes for converting various 8-bit code points to their equivalent ISO 10646
///		UCS-4 code points and vice versa.
///
///	-	(Datetime)  A set of classes representing dates, times and timestamps.  These classes also provide the
///		ability to input and output dates, times and timestamps in a formatted manner.
///
///	-	(Id3v10)  A set of classes which provides the ability to read and write ID3 v1.0 tags.
///
///	-	(Id3v11)  A set of classes which provides the ability to read and write ID3 v1.1 tags.
///
///	-	(Id3v20)  A set of classes which defines the various types of fields used in ID3 v2.x frames.
///
///	-	(Id3v22)  A set of classes which provides the ability to read and write ID3 v2.2 tags.
///
///	-	(Id3v23)  A set of classes which provides the ability to read and write ID3 v2.3 tags.
///
///	-	(Db)  A set of interfaces required to access a database and a set of supporting classes common to all
///		database access implementations.
///
///	-	(Mysql)  A set of classes which implements the interfaces defined in the database access library using
///		the MySQL database.
///
///	@note String data handled by this library uses the UTF-8 character set.  This library is thread-safe.
///		  The code in this library complies to the recommendations contained in the books C++ Coding
///		  Standards, Effective C++ and Effective Modern C++ and the document LFC-CS-0003 - C++ Coding
///		  Standards.doc.
///

#endif // _LFC1_HPP_

//============================================================================================================
//	End of Code
//============================================================================================================
